@@ -105,6 +105,8 @@ class LEDENETHardware:
     remote_rf: bool  # legacy rf remote
     remote_24g: bool  # 2.4ghz remote
     remote_24g_controls: bool  # 2.4ghz remote controls (pair/unpair remotes)
+    auto_on: bool  # turns on when adjusting levels/setting effects
+    dimmable_effects: bool  # supports dimming effects
 
 
 BASE_MODE_MAP = {
@@ -369,6 +371,8 @@ HARDWARE = [
         remote_rf=False,  # verified
         remote_24g=False,
         remote_24g_controls=False,
+        auto_on=False,
+        dimmable_effects=False,
     ),
     LEDENETHardware(
         model="AK001-ZJ200",
@@ -376,6 +380,8 @@ HARDWARE = [
         remote_rf=False,  # verified
         remote_24g=False,
         remote_24g_controls=False,
+        auto_on=False,
+        dimmable_effects=False,
     ),
     LEDENETHardware(
         model="AK001-ZJ210",  # might also be "AK001-ZJ2100"
@@ -383,6 +389,8 @@ HARDWARE = [
         remote_rf=False,  # verified
         remote_24g=False,
         remote_24g_controls=False,
+        auto_on=False,
+        dimmable_effects=False,
     ),
     LEDENETHardware(
         model="AK001-ZJ2101",
@@ -390,6 +398,8 @@ HARDWARE = [
         remote_rf=False,
         remote_24g=False,
         remote_24g_controls=False,
+        auto_on=True,
+        dimmable_effects=False,
     ),
     LEDENETHardware(
         model="AK001-ZJ2104",
@@ -397,6 +407,8 @@ HARDWARE = [
         remote_rf=False,  # verified
         remote_24g=False,
         remote_24g_controls=False,
+        auto_on=True,
+        dimmable_effects=False,
     ),
     LEDENETHardware(
         model="AK001-ZJ2134",  # seen in smart plugs only?
@@ -404,6 +416,8 @@ HARDWARE = [
         remote_rf=False,
         remote_24g=False,
         remote_24g_controls=False,
+        auto_on=False,
+        dimmable_effects=False,
     ),
     LEDENETHardware(
         model="AK001-ZJ2145",
@@ -411,6 +425,8 @@ HARDWARE = [
         remote_rf=False,  # verified
         remote_24g=False,
         remote_24g_controls=False,
+        auto_on=True,
+        dimmable_effects=True,
     ),
     LEDENETHardware(
         model="AK001-ZJ2146",  # seen in smart plugs & Controller RGBCW, but RF remote isn't supported on plugs
@@ -418,6 +434,8 @@ HARDWARE = [
         remote_rf=False,  # verified
         remote_24g=True,
         remote_24g_controls=False,
+        auto_on=True,
+        dimmable_effects=True,
     ),
     LEDENETHardware(
         model="AK001-ZJ2147",  # seen on Controller RGBW
@@ -425,6 +443,8 @@ HARDWARE = [
         remote_rf=False,  # verified
         remote_24g=True,
         remote_24g_controls=False,
+        auto_on=True,
+        dimmable_effects=True,
     ),
     LEDENETHardware(
         model="AK001-ZJ2148",  # seen on older Addressable v3
@@ -432,6 +452,8 @@ HARDWARE = [
         remote_rf=True,  # verified
         remote_24g=True,
         remote_24g_controls=True,
+        auto_on=True,
+        dimmable_effects=True,
     ),
     LEDENETHardware(
         model="AK001-ZJ2149",  # seen on newer Addressable v3
@@ -439,6 +461,17 @@ HARDWARE = [
         remote_rf=True,  # verified
         remote_24g=True,
         remote_24g_controls=True,
+        auto_on=True,
+        dimmable_effects=True,
+    ),
+    LEDENETHardware(
+        model="AK001-ZJ21410",  # seen on newer 0x1E Ceiling lights
+        chip=LEDENETChip.BL602,
+        remote_rf=True,  # verified
+        remote_24g=True,
+        remote_24g_controls=True,
+        auto_on=True,
+        dimmable_effects=True,
     ),
     LEDENETHardware(
         model="HF-A11",  # reported older large box controllers (may be original proto)
@@ -446,6 +479,8 @@ HARDWARE = [
         remote_rf=False,  # unverified
         remote_24g=False,
         remote_24g_controls=False,
+        auto_on=False,
+        dimmable_effects=False,
     ),
     LEDENETHardware(
         model="HF-A11-ZJ002",  # reported older large box controllers (may be original proto)
@@ -453,6 +488,8 @@ HARDWARE = [
         remote_rf=False,  # unverified
         remote_24g=False,
         remote_24g_controls=False,
+        auto_on=False,
+        dimmable_effects=False,
     ),
     LEDENETHardware(
         model="HF-A11-ZJ004",  # reported older large box controllers (may be original proto)
@@ -460,6 +497,8 @@ HARDWARE = [
         remote_rf=False,  # unverified
         remote_24g=False,
         remote_24g_controls=False,
+        auto_on=False,
+        dimmable_effects=False,
     ),
     LEDENETHardware(
         model="HF-A11-ZJ2",  # reported older large box controllers (may be original proto)
@@ -467,6 +506,8 @@ HARDWARE = [
         remote_rf=False,  # unverified
         remote_24g=False,
         remote_24g_controls=False,
+        auto_on=False,
+        dimmable_effects=False,
     ),
     LEDENETHardware(
         model="HF-A11-ZJ201",  # reported older large box controllers (may be original proto)
@@ -474,6 +515,8 @@ HARDWARE = [
         remote_rf=False,  # unverified
         remote_24g=False,
         remote_24g_controls=False,
+        auto_on=False,
+        dimmable_effects=False,
     ),
     LEDENETHardware(
         model="HF-LPB100-ZJ2001",  # reported older large box controllers (may be original proto)
@@ -481,6 +524,8 @@ HARDWARE = [
         remote_rf=False,  # unverified
         remote_24g=False,
         remote_24g_controls=False,
+        auto_on=False,
+        dimmable_effects=False,
     ),
     LEDENETHardware(
         model="HF-LPB100",  # reported on older UFO
@@ -488,6 +533,8 @@ HARDWARE = [
         remote_rf=False,  # unverified
         remote_24g=False,
         remote_24g_controls=False,
+        auto_on=False,
+        dimmable_effects=False,
     ),
     LEDENETHardware(
         model="HF-LPB100-",
@@ -495,6 +542,8 @@ HARDWARE = [
         remote_rf=False,  # unverified
         remote_24g=False,
         remote_24g_controls=False,
+        auto_on=False,
+        dimmable_effects=False,
     ),
     LEDENETHardware(
         model="HF-LPB100-0",  # reported on older UFO
@@ -502,6 +551,8 @@ HARDWARE = [
         remote_rf=False,  # unverified
         remote_24g=False,
         remote_24g_controls=False,
+        auto_on=False,
+        dimmable_effects=False,
     ),
     LEDENETHardware(
         model="HF-LPB100-1",  # reported on older UFO
@@ -509,6 +560,8 @@ HARDWARE = [
         remote_rf=False,  # unverified
         remote_24g=False,
         remote_24g_controls=False,
+        auto_on=False,
+        dimmable_effects=False,
     ),
     LEDENETHardware(
         model="HF-LPB100-ZJ001",
@@ -516,6 +569,8 @@ HARDWARE = [
         remote_rf=False,  # unverified
         remote_24g=False,
         remote_24g_controls=False,
+        auto_on=False,
+        dimmable_effects=False,
     ),
     LEDENETHardware(
         model="HF-LPB100-ZJ011",
@@ -523,6 +578,8 @@ HARDWARE = [
         remote_rf=False,  # unverified
         remote_24g=False,
         remote_24g_controls=False,
+        auto_on=False,
+        dimmable_effects=False,
     ),
     LEDENETHardware(
         model="HF-LPB100-ZJ002",  # seen on older UFO
@@ -530,6 +587,8 @@ HARDWARE = [
         remote_rf=False,  # unverified
         remote_24g=False,
         remote_24g_controls=False,
+        auto_on=False,
+        dimmable_effects=False,
     ),
     LEDENETHardware(
         model="HF-LPB100-ZJ200",  # seen on RGBW Downlight
@@ -537,6 +596,8 @@ HARDWARE = [
         remote_rf=False,  # unverified
         remote_24g=False,
         remote_24g_controls=False,
+        auto_on=False,
+        dimmable_effects=False,
     ),
 ]
 
@@ -587,14 +648,15 @@ MODELS = [
     ),
     LEDENETModel(
         model_num=0x04,
+        # AK001-ZJ100 == v3.09
         # AK001-ZJ200 == v5.20
-        # There are a limited set of these devices that are the mini version
-        # but most are UFOs
+        # There are a limited set of these devices that are the mini version but most are UFOs
         models=[
             "HF-LPB100",
             "HF-LPB100-0",
             "HF-LPB100-1",
             "HF-LPB100-ZJ002",
+            "AK001-ZJ100",
             "AK001-ZJ200",
         ],
         description="UFO Controller RGBW",  # AKA ZJ-WFUF-170F
@@ -668,22 +730,17 @@ MODELS = [
         models=[],
         description="High Voltage Ceiling Light CCT",
         always_writes_white_and_colors=False,  # Formerly rgbwprotocol
-        protocols=[MinVersionProtocol(0, PROTOCOL_LEDENET_8BYTE)],
+        protocols=[MinVersionProtocol(0, PROTOCOL_LEDENET_CCT)],
         mode_to_color_mode={},
         color_modes={COLOR_MODE_CCT},  # Formerly rgbwcapable
-        channel_map={
-            STATE_WARM_WHITE: STATE_RED,
-            STATE_RED: STATE_WARM_WHITE,
-            STATE_COOL_WHITE: STATE_GREEN,
-            STATE_GREEN: STATE_COOL_WHITE,
-        },
+        channel_map={},
         microphone=False,
         device_config=IMMUTABLE_DEVICE_CONFIG,
     ),
     LEDENETModel(
         model_num=0x0B,
         models=[],
-        description="Switch 1c",
+        description="Switch 1 Channel",
         always_writes_white_and_colors=False,  # Formerly rgbwprotocol
         protocols=[MinVersionProtocol(0, PROTOCOL_LEDENET_8BYTE)],
         mode_to_color_mode={},
@@ -739,7 +796,7 @@ MODELS = [
         model_num=0x16,
         models=[],
         description="Magnetic Light CCT",
-        always_writes_white_and_colors=False,  # Formerly rgbwprotocol
+        always_writes_white_and_colors=True,  # Formerly rgbwprotocol
         protocols=[MinVersionProtocol(0, PROTOCOL_LEDENET_8BYTE)],
         mode_to_color_mode={},
         color_modes={COLOR_MODE_CCT},  # Formerly rgbwcapable
@@ -756,7 +813,7 @@ MODELS = [
         model_num=0x17,
         models=[],
         description="Magnetic Light Dimable",
-        always_writes_white_and_colors=False,  # Formerly rgbwprotocol
+        always_writes_white_and_colors=True,  # Formerly rgbwprotocol
         protocols=[MinVersionProtocol(0, PROTOCOL_LEDENET_8BYTE)],
         mode_to_color_mode={},
         color_modes={COLOR_MODE_DIM},  # Formerly rgbwcapable
@@ -767,7 +824,7 @@ MODELS = [
     LEDENETModel(
         model_num=0x18,
         models=[],
-        description="Plant Light",
+        description="Plant Grow Light",
         always_writes_white_and_colors=False,  # Formerly rgbwprotocol
         protocols=[MinVersionProtocol(0, PROTOCOL_LEDENET_8BYTE)],
         mode_to_color_mode={},
@@ -779,7 +836,7 @@ MODELS = [
     LEDENETModel(
         model_num=0x19,
         models=[],
-        description="Socket 2 USB",
+        description="Socket with 2 USB",
         always_writes_white_and_colors=False,  # Formerly rgbwprotocol
         protocols=[MinVersionProtocol(0, PROTOCOL_LEDENET_SOCKET)],
         mode_to_color_mode={},
@@ -791,7 +848,7 @@ MODELS = [
     LEDENETModel(
         model_num=0x1B,
         models=[],
-        description="Spray Light",
+        description="Aroma Fragrance Light",
         always_writes_white_and_colors=False,  # Formerly rgbwprotocol
         protocols=[MinVersionProtocol(0, PROTOCOL_LEDENET_8BYTE)],
         mode_to_color_mode={},
@@ -813,8 +870,21 @@ MODELS = [
         microphone=False,
         device_config=IMMUTABLE_DEVICE_CONFIG,
     ),
+    LEDENETModel(
+        model_num=0x1D,
+        models=[],
+        description="Fill Light",
+        always_writes_white_and_colors=True,  # Formerly rgbwprotocol
+        protocols=[MinVersionProtocol(2, PROTOCOL_LEDENET_8BYTE_AUTO_ON)],
+        mode_to_color_mode={},
+        color_modes={COLOR_MODE_DIM},  # Formerly rgbwcapable
+        channel_map={STATE_WARM_WHITE: STATE_RED, STATE_RED: STATE_WARM_WHITE},
+        microphone=False,
+        device_config=IMMUTABLE_DEVICE_CONFIG,
+    ),
     LEDENETModel(
         model_num=0x1E,  # Should be the same as 0x35
+        # 'AK001-ZJ21410' is v9.9 (with RF remote control support + pairing)
         models=[],
         description="Ceiling Light RGBCW",
         always_writes_white_and_colors=False,  # Formerly rgbwprotocol
@@ -864,9 +934,9 @@ MODELS = [
         model_num=0x33,
         # 'AK001-ZJ100' == v3 - WIFI370 version
         # 'AK001-ZJ2104' == v7 supports turning on by effect/levels set
-        # 'AK001-ZJ2101' == v8.61 - no dimmable effects confirmed, confirmed auto on
+        # 'AK001-ZJ2101' == v8.61, 8.62 (44 key) - no dimmable effects confirmed, confirmed auto on
         # "AK001-ZJ2145" == v9 # no rf support!
-        # "AK001-ZJ2145" == v9.27 # w/IR
+        # "AK001-ZJ2145" == v9.27, 9.33 # w/IR
         # "AK001-ZJ2146" == v10.48 # 2.4ghz support
         # "AK001-ZJ2148" == v10.63 # 2.4ghz support, confirmed to be able to change 2.4G remote settings
         models=[
@@ -1068,7 +1138,7 @@ MODELS = [
     ),
     LEDENETModel(
         model_num=0x97,  # 0x97
-        # AK001-ZJ2146 = v3.11 (has BLE)
+        # AK001-ZJ2146 = v3.11, 3.12 (has BLE)
         models=["AK001-ZJ2134", "AK001-ZJ2146"],
         description="Socket",  # 1 channel
         always_writes_white_and_colors=False,  # Formerly rgbwprotocol
@@ -1124,13 +1194,11 @@ MODELS = [
         models=[],
         description="Addressable v4",
         always_writes_white_and_colors=False,
-        protocols=[
-            MinVersionProtocol(0, PROTOCOL_LEDENET_ADDRESSABLE_A3)
-        ],  # Currently no difference from v3 proto
+        protocols=[MinVersionProtocol(0, PROTOCOL_LEDENET_ADDRESSABLE_A3)],
         mode_to_color_mode={},
         color_modes=COLOR_MODES_ADDRESSABLE,
         channel_map={},
-        microphone=True,  # may be false
+        microphone=False,  # confirmed false
         device_config=NEW_ADDRESABLE_DEVICE_CONFIG,
     ),
     LEDENETModel(
@@ -1138,19 +1206,29 @@ MODELS = [
         models=[],
         description="Addressable v6",
         always_writes_white_and_colors=False,
-        protocols=[
-            MinVersionProtocol(0, PROTOCOL_LEDENET_ADDRESSABLE_A3)
-        ],  # Currently no difference from v3 proto
+        protocols=[MinVersionProtocol(0, PROTOCOL_LEDENET_ADDRESSABLE_A3)],
         mode_to_color_mode={},
         color_modes=COLOR_MODES_ADDRESSABLE,
         channel_map={},
-        microphone=True,  # may be false
+        microphone=True,  # confirmed with mocks to be true
+        device_config=NEW_ADDRESABLE_DEVICE_CONFIG,
+    ),
+    LEDENETModel(
+        model_num=0xA7,
+        models=[],
+        description="Addressable v7",
+        always_writes_white_and_colors=False,
+        protocols=[MinVersionProtocol(0, PROTOCOL_LEDENET_ADDRESSABLE_A3)],
+        mode_to_color_mode={},
+        color_modes=COLOR_MODES_ADDRESSABLE,
+        channel_map={},
+        microphone=True,  # confirmed with mocks to be true
         device_config=NEW_ADDRESABLE_DEVICE_CONFIG,
     ),
     LEDENETModel(
         model_num=0xD1,
         models=[],
-        description="Digital Light",
+        description="Digital Time Light",
         always_writes_white_and_colors=False,  # Formerly rgbwprotocol
         protocols=[MinVersionProtocol(0, PROTOCOL_LEDENET_8BYTE)],
         mode_to_color_mode={},
@@ -1163,7 +1241,7 @@ MODELS = [
         model_num=0xE1,
         models=["AK001-ZJ2104"],
         description="Ceiling Light CCT",
-        always_writes_white_and_colors=False,  # Formerly rgbwprotocol
+        always_writes_white_and_colors=True,  # Formerly rgbwprotocol
         protocols=[MinVersionProtocol(0, PROTOCOL_LEDENET_8BYTE)],
         mode_to_color_mode={},
         color_modes={COLOR_MODE_CCT},  # Formerly rgbwcapable
@@ -1179,12 +1257,17 @@ MODELS = [
     LEDENETModel(
         model_num=0xE2,
         models=[],
-        description="Ceiling Light Assist",
-        always_writes_white_and_colors=False,  # Formerly rgbwprotocol
+        description="Ceiling Light CCT Assist",
+        always_writes_white_and_colors=True,  # Formerly rgbwprotocol
         protocols=[MinVersionProtocol(0, PROTOCOL_LEDENET_8BYTE)],
         mode_to_color_mode={},
-        color_modes=set(),  # no color modes -- UNVERIFIED
-        channel_map={},
+        color_modes={COLOR_MODE_CCT},  # Formerly rgbwcapable
+        channel_map={
+            STATE_WARM_WHITE: STATE_RED,
+            STATE_RED: STATE_WARM_WHITE,
+            STATE_COOL_WHITE: STATE_GREEN,
+            STATE_GREEN: STATE_COOL_WHITE,
+        },
         microphone=False,
         device_config=IMMUTABLE_DEVICE_CONFIG,
     ),
